#######################################################################
#
# Directory/Entry.pm - Stanford Directory entry object
#
# $Id$
#
#----------------------------------------------------------------------
#  Copyright  2000-2006 Board of Trustees, Leland Stanford Jr. University
#
#  This module is free software; you may redistribute it and/or modify it
#  under the same terms as Perl itself.
#######################################################################

package Stanford::Directory::Entry;

use strict;
use vars qw($AUTOLOAD);

# new (constructor) - just bless the hash

sub new {
    my $class = shift;
    my $self = {};
    bless $self, $class;
    return $self;
}

# AUTOLOAD - used to get and set attributes

sub AUTOLOAD {
    my $self = shift;

    my $name = $AUTOLOAD;
    $name =~ s/.*:://;               # strip fully-qualified portion
    return if $name =~ /DESTROY/;    # don't do DESTROY
    $name = lc($name);

    push(@{$self->{$name}},@_) if (@_);

    return (exists $self->{$name}) ? @{$self->{$name}} : ();
}

# as_string - just a toy to list an Entry for debugging and such

sub as_string {
    my $self = shift;
    my $string;
    my $values;

    my $width = 25;    my $fill = sprintf("\n%${width}s + ","");

    foreach (@_ ? @_ : keys %$self) {
	my $key  = lc($_);
	$values  = exists $self->{$key} ? join($fill,@{$self->{$key}}) : "";
	$string .= sprintf("%${width}s : %s\n", $_, $values);
    }
    return $string;
}


1;
__END__

=head1 NAME

Stanford::Directory::Entry - Stanford Directory entry object

=head1 DESCRIPTION

B<Stanford::Directory::Entry> is a light-weight object for storing and
accessing Stanford Directory entries.  It is included with the
B<Stanford::Directory> object; other programs never need to explicitly
include it.

=head1 METHODS

B<Stanford::Directory::Entry> has only the AUTOLOAD method.  Any
method invoked is treated as a request to set or get the Directory
entry attribute corresponding to the name of the method.  If a method
is invoked with arguments, those values are added to the data for the
attribute.  Each method returns an array containing all of the data
for the attribute.

=head1 AUTHORS

Rob Riepel, riepel@stanford.edu

Quanah Gibson-Mount, quanah@stanford.edu

=head1 SEE ALSO

Stanford::Directory

=head1 COPYRIGHT AND LICENSE

    Copyright 2000-2004 Board of Trustee, Leland Stanford Jr. University

    This module is free software; you may redistribute it and/or modify it
    under the same terms as Perl itself.

=cut
